@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Iterator.pm
-## Version v1.0.0
+## Version v1.1.0
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2021/03/20
+## Modified 2022/02/27
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -20,9 +20,12 @@ BEGIN
     use Module::Generic::Array;
     use Scalar::Util ();
     use Want;
-    our( $VERSION ) = 'v1.0.0';
+    our( $VERSION ) = 'v1.1.0';
 };
 
+use strict;
+no warnings 'redefine';
+
 sub init
 {
     my $self = CORE::shift( @_ );
